@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-import base64
 import hashlib
 import json
 import os
@@ -25,6 +24,7 @@ from typing import List
 import utoken
 
 from . import exceptions
+from .ignore import get_not_ignored_files
 
 
 class Pie(object):
@@ -117,6 +117,9 @@ class Pie(object):
         if not os.path.isfile(filepath):
             raise FileNotFoundError(f'File "{filepath}" not found')
 
+        if './' not in filepath:
+            filepath = os.path.join('.', filepath)
+
         file_info = {
             'filename': filepath,
             'commits': []
@@ -141,6 +144,7 @@ class Pie(object):
 
         file_lines = {}
 
+        # removing "\n" only from the end of the line
         for line, text in enumerate(file):
             if text[-1::] == '\n':
                 text = text[:-1]
@@ -359,6 +363,17 @@ class Pie(object):
                         'status': 'uncommitted'
                     })
 
+        not_ignored_files = get_not_ignored_files()
+
+        for filepath in not_ignored_files:
+            filepath = os.path.join('.', filepath)
+
+            if filepath not in tracked_files.keys():
+                files_status.append({
+                    'filepath': filepath,
+                    'status': 'untracked'
+                })
+
         return files_status
 
     def commit(self, filepath_list: list, message: str) -> dict:
@@ -378,6 +393,9 @@ class Pie(object):
         file_refs = {}
 
         for filepath in filepath_list:
+            if './' not in filepath:
+                filepath = os.path.join('.', filepath)
+
             file_info = tracked_files.get(filepath)
 
             if file_info:
